sched: Dont use fixed-size buffer for task names.
[paraslash.git] / stdout.c
index 4554145f3d24883e828c849e856e4eca2f428cc6..0ff24e92b1b7065b8c5a2267c70817487363d251 100644 (file)
--- a/stdout.c
+++ b/stdout.c
@@ -27,7 +27,7 @@
  */
 static void stdout_pre_select(struct sched *s, struct task *t)
 {
-       struct stdout_task *sot = container_of(t, struct stdout_task, task);
+       struct stdout_task *sot = task_context(t);
        int ret;
 
        ret = btr_node_status(sot->btrn, 0, BTR_NT_LEAF);
@@ -48,7 +48,7 @@ static void stdout_pre_select(struct sched *s, struct task *t)
  */
 static int stdout_post_select(struct sched *s, struct task *t)
 {
-       struct stdout_task *sot = container_of(t, struct stdout_task, task);
+       struct stdout_task *sot = task_context(t);
        struct btr_node *btrn = sot->btrn;
        int ret;
        char *buf;
@@ -85,21 +85,24 @@ out:
        }
        return ret;
 }
+
 /**
* Initialize a stdout task structure with default values.
  *
* \param sot The stdout task structure.
  *
- * This fills in the pre/post select function pointers of the task structure
- * given by \a sot.
+ * This sets up \a sot and registers a task with \a sot as context pointer.
  */
-void stdout_set_defaults(struct stdout_task *sot)
+void stdout_task_register(struct stdout_task *sot, struct sched *s)
 {
        int ret;
-
-       sot->task.pre_select = stdout_pre_select;
-       sot->task.post_select = stdout_post_select;
-       sprintf(sot->task.status, "stdout");
+       struct task_info ti = {
+               .pre_select = stdout_pre_select,
+               .post_select = stdout_post_select,
+               .context = sot,
+               .name = "stdout",
+       };
 
        /* See stdin.c for details. */
        ret = fcntl(STDOUT_FILENO, F_GETFL);
@@ -109,4 +112,5 @@ void stdout_set_defaults(struct stdout_task *sot)
        }
        sot->fd_flags = ret;
        sot->must_set_nonblock_flag = (sot->fd_flags & O_NONBLOCK) == 0;
+       sot->task = task_register(&ti, s);
 }
@@ -85,21 +85,24 @@ out:
 /**
- * Initialize a stdout task structure with default values.
+ * Register a stdout task structure.
  *
@@ -85,21 +85,24 @@ out:
  *
- * \param sot The stdout task structure.
+ * \param sot The stdout task structure to register.
+ * \param s The task will be added to this scheduler's task list.
  *